{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "2b311221-42be-42d4-a354-2648605d3a6c",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "(sec:selection_rules)=\n",
    "# Selection rules"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "781129c6-5ace-4b08-907f-aa63cbd0e8a7",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "Spectrum intensities are proportional to the square modulus of transition moments\n",
    "\n",
    "$$\n",
    "\\sigma_{f\\leftarrow i} \\propto\n",
    "\\left| \n",
    "\\langle \\Psi_f | \\hat{\\Omega} | \\Psi_i \\rangle \n",
    "\\right|^2\n",
    "$$\n",
    "\n",
    "where the quantum mechanical operator $\\hat{\\Omega}$ provides the coupling between the molecular system and the external electromagnetic fields. Examples of such coupling operators are the electric and magnetic dipole moment operators and the electric quadrupole moment operator. \n",
    "\n",
    "The study of the symmetry groups of molecular systems has immediate and powerful practical consequences. Specifically, we can predict when transition moments (and therefore also spectrum intensities) are zero due to reasons of symmetry. Such analyses are based on the result that an integral such as the transition moment is nonzero if and only if the direct product of the irreducible representations involved is equal to the all-symmetric representation\n",
    "\n",
    "$$\n",
    "\\Gamma(\\Psi_f) \\otimes\n",
    "\\Gamma(\\hat{\\Omega}) \\otimes\n",
    "\\Gamma(\\Psi_i) = \\Gamma(\\hat{I})\n",
    "$$"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3602a525-6f4a-406a-8a3b-c4810dd9119f",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "Let us view a simple and concrete example how symmetry can be used to determine a few selection rules for electric- and magnetic-field induced transitions of a $\\pi$-stacked system. We will use the ethylene dimer with a separation distance of 4 Å as an illustration. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "c72ea380-4585-4a28-beca-7dd06b5da804",
   "metadata": {
    "editable": true,
    "scrolled": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "dimer_xyz = \"\"\"12\n",
    "\n",
    "C        0.67759997    0.00000000   -2.00000000\n",
    "C       -0.67759997    0.00000000   -2.00000000\n",
    "H        1.21655197    0.92414474   -2.00000000\n",
    "H        1.21655197   -0.92414474   -2.00000000\n",
    "H       -1.21655197   -0.92414474   -2.00000000\n",
    "H       -1.21655197    0.92414474   -2.00000000\n",
    "C        0.67759997    0.00000000    2.00000000\n",
    "C       -0.67759997    0.00000000    2.00000000\n",
    "H        1.21655197    0.92414474    2.00000000\n",
    "H        1.21655197   -0.92414474    2.00000000\n",
    "H       -1.21655197   -0.92414474    2.00000000\n",
    "H       -1.21655197    0.92414474    2.00000000\"\"\""
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "364da8ba-28d1-4bb1-ba18-d68b277d5003",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_17032450660061262\"  style=\"position: relative; width: 400px; height: 300px;\">\n        <p id=\"3dmolwarning_17032450660061262\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_17032450660061262 = null;\nvar warn = document.getElementById(\"3dmolwarning_17032450660061262\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_17032450660061262 = $3Dmol.createViewer(document.getElementById(\"3dmolviewer_17032450660061262\"),{backgroundColor:\"white\"});\nviewer_17032450660061262.zoomTo();\n\tviewer_17032450660061262.addModel(\"12\\n\\nC        0.67759997    0.00000000   -2.00000000\\nC       -0.67759997    0.00000000   -2.00000000\\nH        1.21655197    0.92414474   -2.00000000\\nH        1.21655197   -0.92414474   -2.00000000\\nH       -1.21655197   -0.92414474   -2.00000000\\nH       -1.21655197    0.92414474   -2.00000000\\nC        0.67759997    0.00000000    2.00000000\\nC       -0.67759997    0.00000000    2.00000000\\nH        1.21655197    0.92414474    2.00000000\\nH        1.21655197   -0.92414474    2.00000000\\nH       -1.21655197   -0.92414474    2.00000000\\nH       -1.21655197    0.92414474    2.00000000\");\n\tviewer_17032450660061262.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewer_17032450660061262.rotate(-90,\"x\");\nviewer_17032450660061262.render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_17032450660061262\"  style=\"position: relative; width: 400px; height: 300px;\">\n",
       "        <p id=\"3dmolwarning_17032450660061262\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_17032450660061262 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_17032450660061262\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "viewer_17032450660061262 = $3Dmol.createViewer(document.getElementById(\"3dmolviewer_17032450660061262\"),{backgroundColor:\"white\"});\n",
       "viewer_17032450660061262.zoomTo();\n",
       "\tviewer_17032450660061262.addModel(\"12\\n\\nC        0.67759997    0.00000000   -2.00000000\\nC       -0.67759997    0.00000000   -2.00000000\\nH        1.21655197    0.92414474   -2.00000000\\nH        1.21655197   -0.92414474   -2.00000000\\nH       -1.21655197   -0.92414474   -2.00000000\\nH       -1.21655197    0.92414474   -2.00000000\\nC        0.67759997    0.00000000    2.00000000\\nC       -0.67759997    0.00000000    2.00000000\\nH        1.21655197    0.92414474    2.00000000\\nH        1.21655197   -0.92414474    2.00000000\\nH       -1.21655197   -0.92414474    2.00000000\\nH       -1.21655197    0.92414474    2.00000000\");\n",
       "\tviewer_17032450660061262.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewer_17032450660061262.rotate(-90,\"x\");\n",
       "viewer_17032450660061262.render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import py3Dmol\n",
    "\n",
    "viewer = py3Dmol.view(width=400, height=300)\n",
    "\n",
    "viewer.addModel(dimer_xyz)\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "\n",
    "# rotate for a better initial view\n",
    "viewer.rotate(-90, \"x\")\n",
    "\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "29c66a27-96ab-42cf-ac6b-a0d836fa24f9",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "This system belongs to the $D_{2h}$ point group with eight irreducible representations presented in the [character table](character_table_d2h).\n",
    "\n",
    "The ground (or initial) state is closed-shell in nature and we thus have\n",
    "\n",
    "$$\n",
    "\\Gamma(\\Psi_i) = A_g\n",
    "$$\n",
    "\n",
    "We start by performing an SCF optimization of this ground state at the DFT level of theory using the `BHANDHLYP` functional to view the molecular orbitals (MOs) and, more, specifically, their symmetry character. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "349f5f46-7b10-4687-989e-e49656fb9783",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "* Warning * Environment variable OMP_NUM_THREADS not set.\n",
      "* Warning * Setting OMP_NUM_THREADS to 6.\n"
     ]
    }
   ],
   "source": [
    "import veloxchem as vlx"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "335fcf6c-bd5d-4501-acb8-1e6e79715970",
   "metadata": {
    "editable": true,
    "scrolled": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [],
   "source": [
    "scf_drv = vlx.ScfRestrictedDriver()\n",
    "scf_drv.ostream.mute()\n",
    "\n",
    "molecule = vlx.Molecule.read_xyz_string(dimer_xyz)\n",
    "basis = vlx.MolecularBasis.read(molecule, \"6-31g\", ostream=None)\n",
    "\n",
    "scf_drv.xcfun = \"bhandhlyp\"\n",
    "scf_results = scf_drv.compute(molecule, basis)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "d8c0cf35-b677-49ee-a9e5-56d651392a21",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "959212fd218e4b509a678e223353b1ab",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Output()"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "9c2e3ad14bc74821a7df25aa8469f2dc",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Dropdown(description='Orbital:', index=15, options=(('  1 occ=2.000 ene=-10.584', 0), ('  2 occ=2.000 ene=-10.…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "viewer = vlx.OrbitalViewer()\n",
    "viewer.plot(molecule, basis, scf_drv.mol_orbs)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "b1054d0f-8ab6-4719-90b5-c71d9e745967",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "While one can change the selection of MO in the pull-down menu in a Jupyter notebook, this HTML page is static. For this reason, the $\\pi$-conjugated frontier orbitals have been collected in the figure below, which represents a slight variation of an illustration found in Ref. {cite}`Norman2014`."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "4990425f-c31c-4edc-88db-cfca2f841f8f",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "![H-aggregate](../../img/spec_prop/h-aggregate.png) "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "733000ca-33e6-4120-8f09-94242eacaf31",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "The MOs of supramolecular system can be considered as linear combinations of the $\\pi$- and $\\pi^*$-orbitals of the monomers with main characters as follows\n",
    "\n",
    "\\begin{align*}\n",
    "|i^-\\rangle = \\pi_1 - \\pi_2 \\\\\n",
    "|i^+\\rangle = \\pi_1 + \\pi_2 \\\\\n",
    "|f^-\\rangle = \\pi_1^* - \\pi_2^* \\\\\n",
    "|f^+\\rangle = \\pi_1^* + \\pi_2^* \\\\\n",
    "\\end{align*}\n",
    "\n",
    "where, respectively, $i$ and $f$ denote initial and final electronic states in the excitation process. With two initial and two final orbitals, we can form four excited states. \n",
    "\n",
    "The symmetries of these MOs are straightforwardly identified from the [character table](character_table_d2h) and given in the figure with the conventional use of small letters for denoting symmetries of MOs and capital letters for symmetries of multi-electron wave functions.\n",
    "\n",
    "- State $| \\sigma\\rangle$ is lowest in energy and (primarily) associated with a HOMO–LUMO excitation giving rise to a ${}^1B_{2g}$ state. This state is electric-dipole forbidden. However, it couples to the ground state by means of the magnetic-dipole operator $\\hat{m}_y$ that transforms as the rotation $R_y$ in the [character table](character_table_d2h).\n",
    "\n",
    "- State $| \\gamma\\rangle$ follows next in energy and is (primarily) associated with a mix of (HOMO-1)–LUMO and HOMO–(LUMO+1) excitations giving rise to a ${}^1B_{3u}$ state. This state is magnetic-dipole forbidden. However, it couples to the ground state by means of the electric-dipole operator $\\hat{\\mu}_x$ that transforms as the coordinate $x$ in the [character table](character_table_d2h).\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "2eaccc85-57cb-464e-8486-2160f5446cf4",
   "metadata": {
    "editable": true,
    "scrolled": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [],
   "source": [
    "lreig_drv = vlx.LinearResponseEigenSolver()\n",
    "lreig_drv.ostream.mute()\n",
    "\n",
    "lreig_drv.nstates = 4\n",
    "\n",
    "lreig_results = lreig_drv.compute(molecule, basis, scf_results)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "09624e0a-6794-46a4-b410-87962416d473",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "   E (eV)  mu_x    mu_y    mu_z    m_x     m_y     m_z     f       R       \n",
      "------------------------------------------------------------------------\n",
      "  7.5915 -0.0000 -0.0000  0.0000  0.0000 -0.9272 -0.0000  0.0000  0.0000\n",
      "  8.2471  1.6703  0.0000 -0.0000 -0.0000 -0.0000  0.0000  0.5637 -0.0000\n",
      "  8.4311  0.9185  0.0000 -0.0000 -0.0000  0.0000  0.0000  0.1743 -0.0000\n",
      "  8.7460  0.0000 -0.0000 -0.0000  0.0000 -0.4909 -0.0000  0.0000  0.0000\n"
     ]
    }
   ],
   "source": [
    "print(f\"   {'E (eV)':8s}{'mu_x':8s}{'mu_y':8s}{'mu_z':8s}{'m_x':8s}{'m_y':8s}{'m_z':8s}{'f':8s}{'R':8s}\")\n",
    "print(72 * \"-\")\n",
    "\n",
    "for E, e, m, f, R in zip(\n",
    "    lreig_results[\"eigenvalues\"],\n",
    "    lreig_results[\"electric_transition_dipoles\"],\n",
    "    lreig_results[\"magnetic_transition_dipoles\"],\n",
    "    lreig_results[\"oscillator_strengths\"],\n",
    "    lreig_results[\"rotatory_strengths\"],\n",
    "):\n",
    "    print(\n",
    "        f\"{E*27.2114:8.4f}{e[0]:8.4f}{e[1]:8.4f}{e[2]:8.4f}{m[0]:8.4f}{m[1]:8.4f}{m[2]:8.4f}{f:8.4f}{R:8.4f}\"\n",
    "    )"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "b29074e5-299b-45ca-9092-602f5286ea8f",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "So a symmetry analysis allows us to understand the UV/vis absorption and circular dichroism (CD) spectra of H-stacked aggregates. In absorption spectroscopy, the $\\pi\\pi^*$-band of the monomer becomes split into a lower dark band and an upper bright band that acquires the intensity from the two monomers. In CD spectroscopy, none of the bands gives rise to a signal. However, in a twisted supramolecular configuration, the symmetry of the system becomes lower and a bisignate excitonic band is formed from the two Frenkel states {cite}`Norman2014`."
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.7"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
